@@ -62,6 +62,8 @@ static struct keywords config_keywords[] =
     { "#", CONFIG_KEYWORD_COMMENT },
     { "<directory", CONFIG_KEYWORD_DIRECTORY_START },
     { "</directory>", CONFIG_KEYWORD_DIRECTORY_END },
+    { "<modules>", CONFIG_KEYWORD_SYSTEM_START },
+    { "</modules>", CONFIG_KEYWORD_SYSTEM_END },
     { "<system>", CONFIG_KEYWORD_SYSTEM_START },
     { "</system>", CONFIG_KEYWORD_SYSTEM_END },
     { "include", CONFIG_KEYWORD_INCLUDE },
