@@ -264,8 +264,6 @@ void lowercase_string( char *string )
 **
 **    Purpose:  get the string up to the token, returns the
 **              start of the string after the token, NULL if not found.
-**              caller is responsible for knowing if there is sufficient
-**              space in the result buffer!
 **
 ******************************************************************************/
 
@@ -920,19 +918,25 @@ long osi_get_time()
 
 char * osi_time_to_string( long time )
 {
-    static char time_buffer[25];
-    time_t time_value = time;
-    char *time_string = (char *)ctime( &time_value );
+    static char buf[40];
 
-    time_buffer[0] = '\0';
+    time_t curtime;
+    struct tm *loc;
 
-    if( time_string != NULL )
-    {
-        osi_strlcpy( time_buffer, time_string, sizeof( time_buffer ) );
-        time_buffer[24] = '\0';
-    }
+    curtime = time;
+    loc = localtime( &curtime );
 
-    return time_buffer;
+    /* based on RFC 2822 it should be:
+    3.3. Date and Time Specification
+    ...
+    date-time       =       [ day-of-week "," ] date FWS time [CFWS]
+    ...
+    */
+
+    strftime( buf, sizeof(buf) ,"%a, %e %b %Y %H:%M:%S %z", loc );
+    buf[39] = '\0';
+
+    return buf;
 }
 
 
