@@ -31,6 +31,7 @@
 #define MAX_HOST_BRIEF_NAME_LENGTH	       128
 #define MAX_HOST_BRIEF_DESCRIPTION_LENGTH  255
 #define MAX_HOST_BRIEF_NOTIFY_EMAIL_LENGTH 128
+#define MAX_HOST_BRIEF_DB_NAME_LENGTH      10
 #define MAX_HOST_BRIEF_CONFIG_LENGTH       64
 
 #define HOST_SESSION_KEY_LENGTH	  	       64
@@ -64,7 +65,7 @@ typedef struct OSI_HOST_BRIEF
     char host[MAX_HOST_BRIEF_NAME_LENGTH];
     char description[MAX_HOST_BRIEF_DESCRIPTION_LENGTH];
     char session_key[HOST_SESSION_KEY_LENGTH];
-    char base_db[MAX_HOST_BRIEF_NAME_LENGTH];
+    char base_db[MAX_HOST_BRIEF_DB_NAME_LENGTH];
     char notify_email[MAX_HOST_BRIEF_NOTIFY_EMAIL_LENGTH];
     char config[MAX_HOST_BRIEF_CONFIG_LENGTH];
 
