@@ -196,7 +196,7 @@ PCHAR ip_to_name( UINT ipaddr, PCHAR name, int namelen )
 }
 
 
-void process_windows_ports( SCANNER *scanner )
+void process_ports_windows( SCANNER *scanner )
 {
 	DWORD		error, dwSize;
 	HANDLE		hProcessSnap;
@@ -254,7 +254,7 @@ void process_windows_ports( SCANNER *scanner )
 
 	 format for records is:
 	
-     key:     TCP:<port>
+     key:     TCP:<local_addr:port>
 	 record:  TCP:<port>;<process_name>;<process_id>;<local_addr>;<remote_addr>
 
      */	
@@ -271,7 +271,9 @@ void process_windows_ports( SCANNER *scanner )
                          sizeof( record.module_name ) );
 
             osi_snprintf( record.name, sizeof( record.name ),
-                          "TCP:%d", htons(tcpTable->table[i].dwLocalPort) );
+                          "TCP:%s:%d",
+                    ip_to_name( tcpTable->table[i].dwLocalAddr, localname, 255),
+                         htons(tcpTable->table[i].dwLocalPort) );
 
             osi_snprintf( record.data, sizeof( record.data ),
               		      "TCP:%d;exe=%s;pid=%d;local=%s;remote=%s",
@@ -323,10 +325,146 @@ void process_windows_ports( SCANNER *scanner )
 
 #endif /* WIN32 */
 
+#if defined(DISABLED)
+
+#define TCP_FILE  "/proc/net/tcp"
+#define TCP6_FILE "/proc/net/tcp6"
+#define UDP_FILE  "/proc/net/udp"
+
+void process_proc_file( SCANNER *scanner, const char *filename )
+{
+    FILE *file;
+    char line[1024];
+    char *data;
+    char *protocol = "TCP";
+
+    SCAN_RECORD_TEXT_1 record;
+
+    if ( ( scanner == NULL ) || ( filename == NULL ) )
+    {
+        return;
+    }
+
+    if( ( file = osi_fopen( filename, "r", 0 ) ) == NULL )
+    {
+        log_error( "unable to open proc file (%s).", filename );
+        return;
+    }
+
+    /* determine protocol. */
+
+    if ( filename == UDP_FILE )
+    {
+        protocol = "UDP";
+    }
+
+    /* skip first line, it is the header. */
+
+    fgets( line, sizeof(line), file );
+
+    /* read other lines. */
+
+    while( ( data = fgets( line, sizeof( line ), file ) ) != NULL )
+    {
+        char crap[255];
+        char local_addr[255];
+        char local_port[16];
+        char remote_addr[255];
+        char state[5];
+
+        char *temp = NULL;
+        int port = 0;
+
+        /* file format is: id local remote state */
+
+        temp = get_token( line, crap, sizeof(crap) );
+
+        /* get local address and port. */
+
+        temp = get_string_up_to_token( temp, local_addr,
+                                       sizeof(local_addr), ':' );
+
+        temp = get_token( temp, local_port, sizeof(local_port) );
+
+        /* get remote address. */
+
+        temp = get_string_up_to_token( temp, remote_addr,
+                                       sizeof(remote_addr), ':' );
+
+        temp = get_token( temp, crap, sizeof(crap) );
+
+        /* get socket state. */
+
+        temp = get_token( temp, state, sizeof(state) );
+
+        /* if TCP, and not in LISTEN state, we bail. */
+
+        if ( filename != UDP_FILE && strcmp( state, "0A" ) != 0 )
+        {
+            continue; 
+        }
+
+        /* if local is either IPV4 or IPV6 127.0.0.1, bail. */
+
+        if ( ( strcmp( local_addr, "0100007F" ) == 0 ) ||
+           ( strcmp( local_addr, "00000000000000000000000001000000" ) == 0 ) )
+        {
+            continue;
+        }
+
+        /* convert hex into readable. */
+
+        sscanf( local_port, "%X", &port );
+
+        if ( atoi( local_addr ) == 0 )
+        {
+            strcpy( local_addr, "0" );
+        }        
+
+        if ( atoi( remote_addr ) == 0 )
+        {
+            strcpy( remote_addr, "0" );
+        }
+
+        /* populate and send scan record. */
+
+        initialize_scan_record( (SCAN_RECORD *)&record,
+                                SCAN_RECORD_TYPE_TEXT_1 );
+
+        osi_strlcpy( record.module_name, MODULE_NAME,
+                     sizeof( record.module_name ) );
+
+        osi_snprintf( record.name, sizeof( record.name ), "%s:%s:%d",
+                      protocol, local_addr, port );
+
+        osi_snprintf( record.data, sizeof( record.data ),
+                      "%s:%d;local=%s;remote=%s",
+                      protocol, port,local_addr,remote_addr );
+
+        send_scan_data( scanner, (SCAN_RECORD *)&record );
+        
+    }
+
+    fclose(file);
+}
+
+void process_ports_linux( SCANNER *scanner )
+{
+    process_proc_file( scanner, TCP_FILE );
+    process_proc_file( scanner, TCP6_FILE );
+    process_proc_file( scanner, UDP_FILE );
+}
+
+#endif
+
 void mod_ports( SCANNER *scanner )
 {
 #ifdef WIN32
-    process_windows_ports( scanner );
-#endif /* WIN32 */
+    process_ports_windows( scanner );
+#endif
+
+#if defined(DISABLED)
+    process_ports_linux( scanner );
+#endif 
 }
 
