@@ -610,16 +610,23 @@ void process_hello( SSL *ssl, CONTROL_REQUEST *request )
 
 void process_send_notify_test( SSL *ssl, CONTROL_REQUEST *request )
 {
-    OSI_ERROR error;
+    MD_NOTIFY_CTX ctx;
 
-    if( md_notify_send_test( config->notify_email, &error ) == TRUE )
+    md_notify_init( &ctx, NOTIFY_TYPE_TEST );
+    ctx.email = config->notify_email;
+
+    md_notify( &ctx );
+
+    /* no error was produced, assume success. */
+
+    if ( ( ctx.error.type == 0 ) && ( ctx.error.message[0] == 0 ) )
     {
         osi_ssl_write_success_message( ssl );
     }
 
     else
     {
-        osi_ssl_write_error_message( 0, error.message, ssl );
+        osi_ssl_write_error_message( 0, ctx.error.message, ssl );
     }
 }
 
@@ -1742,6 +1749,14 @@ void process_new_host( SSL *ssl, CONTROL_REQUEST *request )
     new_host.schedule_start   = host_brief->schedule_start;
     new_host.schedule_period  = host_brief->schedule_period;
 
+    /* no schedule start specified, this will lead to the scheduler */
+    /* ignoring this client, we set it to a minute ago.             */
+
+    if ( new_host.schedule_start == 0 )
+    {
+        new_host.schedule_start = ( osi_get_time() - 61 );
+    }
+
     if( osi_write_host( &new_host ) )
     {
         /* we kick the scheduler because we have added a new host. */
