@@ -534,11 +534,21 @@ void md_create_payload( MD_NOTIFY_CTX *ctx )
 
     /* setup our hostname. */
 
-    gethostname( ctx->hostname, sizeof(ctx->hostname) );
+    if( config->http_host[0] && strcmp( config->http_host, "" ) != 0 )
+    {
+        osi_strlcpy( ctx->hostname, config->http_host, sizeof(ctx->hostname) );
+    }
+
+    else
+    {
+        gethostname( ctx->hostname, sizeof(ctx->hostname) );
+    }
+
 
     switch( ctx->type )
     {
         case NOTIFY_TYPE_LOG:
+        case NOTIFY_TYPE_REPORT:
 
             if( ( config->http_port > 0 ) && ( ctx->show_url ) )
             {
@@ -551,7 +561,7 @@ void md_create_payload( MD_NOTIFY_CTX *ctx )
 
                 osi_snprintf( ctx->payload, sizeof( ctx->payload ),
                               NOTIFY_UPDATE_URL_FORMAT,
-                              ctx->db_name, ctx->host, config->http_port,
+                              ctx->db_name, ctx->hostname, config->http_port,
                               ctx->host, ctx->db_name, filename );
             }
 
